@@ -1,5 +1,6 @@
 from sqlalchemy import Unicode
 from sqlalchemy.dialects.postgresql import JSONB
+from six import string_types
 
 from jet_bridge_base.fields import field, CharField, BooleanField
 from jet_bridge_base.filters import lookups
@@ -19,6 +20,16 @@ def json_icontains(qs, column, value):
 def coveredby(qs, column, value):
     return qs.filter(column.ST_CoveredBy(value))
 
+def safe_array(value):
+    if isinstance(value, list):
+        return value
+    elif isinstance(value, string_types):
+        if value != '':
+            return value.split(',')
+        else:
+            return []
+    else:
+        value
 
 class Filter(object):
     field_class = field
@@ -29,7 +40,7 @@ class Filter(object):
         lookups.LT: {'operator': '__lt__'},
         lookups.LTE: {'operator': '__le__'},
         lookups.ICONTAINS: {'operator': 'ilike', 'post_process': lambda x: '%{}%'.format(x)},
-        lookups.IN: {'operator': 'in_', 'field_class': CharField, 'field_kwargs': {'many': True}, 'pre_process': lambda x: filter(lambda f: f != '', x.split(','))},
+        lookups.IN: {'operator': 'in_', 'field_class': CharField, 'field_kwargs': {'many': True}, 'pre_process': lambda x: safe_array(x)},
         lookups.STARTS_WITH: {'operator': 'ilike', 'post_process': lambda x: '{}%'.format(x)},
         lookups.ENDS_WITH: {'operator': 'ilike', 'post_process': lambda x: '%{}'.format(x)},
         lookups.IS_NULL: {'operator': lambda x: ('__eq__', None) if x else ('isnot', None), 'field_class': BooleanField},
@@ -37,10 +48,11 @@ class Filter(object):
         lookups.COVEREDBY: {'operator': False, 'func': coveredby}
     }
 
-    def __init__(self, name=None, column=None, lookup=lookups.DEFAULT_LOOKUP):
+    def __init__(self, name=None, column=None, lookup=lookups.DEFAULT_LOOKUP, exclude=False):
         self.name = name
         self.column = column
         self.lookup = lookup
+        self.exclude = exclude
 
     def clean_value(self, value):
         return value
@@ -67,9 +79,16 @@ class Filter(object):
             return func(qs, self.column, value)
         elif callable(operator):
             op = operator(value)
-            return qs.filter(getattr(self.column, op[0])(op[1]))
+
+            if self.exclude:
+                return qs.filter(~getattr(self.column, op[0])(op[1]))
+            else:
+                return qs.filter(getattr(self.column, op[0])(op[1]))
         else:
-            return qs.filter(getattr(self.column, operator)(value))
+            if self.exclude:
+                return qs.filter(~getattr(self.column, operator)(value))
+            else:
+                return qs.filter(getattr(self.column, operator)(value))
 
     def filter(self, qs, value):
         value = self.clean_value(value)
