@@ -1,11 +1,6 @@
 import logging
 
-from jet_bridge_base import settings
-
-
 logger = logging.getLogger('jet_bridge')
-level = logging.DEBUG if settings.DEBUG else logging.INFO
-
 ch = logging.StreamHandler()
 
 
@@ -22,7 +17,8 @@ class Formatter(logging.Formatter):
 formatter = Formatter('%(asctime)s %(levelname)s %(message)s', '%Y-%m-%d %H:%M:%S')
 
 ch.setFormatter(formatter)
-ch.setLevel(level)
-
-logger.setLevel(level)
 logger.addHandler(ch)
+
+def set_logger_level(level):
+    ch.setLevel(level)
+    logger.setLevel(level)
