@@ -1,4 +1,5 @@
 from sqlalchemy import desc, case
+from sqlalchemy.exc import SQLAlchemyError
 from sqlalchemy.orm import load_only
 
 from jet_bridge_base import fields
@@ -44,12 +45,21 @@ def get_reset_order_serializer(Model, queryset, session):
                 qs = qs.order_by(*order_by)
 
             i = 1
-            items = qs.options(load_only(ordering_field)).all()
+
+            try:
+                items = qs.options(load_only(ordering_field)).all()
+            except SQLAlchemyError:
+                queryset.session.rollback()
+                raise
 
             for instance in items:
                 setattr(instance, ordering_field, i)
                 i += 1
 
-            session.commit()
+            try:
+                session.commit()
+            except SQLAlchemyError:
+                session.rollback()
+                raise
 
     return ResetOrderSerializer
