@@ -4,7 +4,7 @@ from sqlalchemy.sql import sqltypes
 from sqlalchemy.exc import SQLAlchemyError
 
 from jet_bridge_base import fields
-from jet_bridge_base.db import create_session
+from jet_bridge_base.db import create_session, get_type_code_to_sql_type
 from jet_bridge_base.exceptions.sql import SqlError
 from jet_bridge_base.exceptions.validation_error import ValidationError
 from jet_bridge_base.fields.sql_params import SqlParamsSerializers
@@ -13,7 +13,7 @@ from jet_bridge_base.filters.filter import EMPTY_VALUES
 from jet_bridge_base.filters.model_group import get_query_func_by_name, get_query_lookup_func_by_name
 from jet_bridge_base.filters.filter_for_dbfield import filter_for_data_type
 from jet_bridge_base.serializers.serializer import Serializer
-from jet_bridge_base.utils.db_types import map_query_type
+from jet_bridge_base.utils.db_types import map_to_sql_type, sql_to_map_type
 
 
 class ColumnSerializer(Serializer):
@@ -23,7 +23,7 @@ class ColumnSerializer(Serializer):
 
 class FilterItemSerializer(Serializer):
     name = fields.CharField()
-    value = fields.CharField(required=False)
+    value = fields.RawField(allow_many=True, required=False)
 
 
 class AggregateSerializer(Serializer):
@@ -38,6 +38,17 @@ class GroupSerializer(Serializer):
     yFunc = fields.CharField()
 
 
+class GroupsItemSerializer(Serializer):
+    xColumn = fields.CharField()
+    xLookup = fields.CharField(required=False)
+
+
+class GroupsSerializer(Serializer):
+    xColumns = GroupsItemSerializer(many=True)
+    yColumn = fields.CharField(required=False)
+    yFunc = fields.CharField()
+
+
 class SqlSerializer(Serializer):
     query = fields.CharField()
     offset = fields.IntegerField(required=False)
@@ -48,6 +59,7 @@ class SqlSerializer(Serializer):
     filters = FilterItemSerializer(many=True, required=False)
     aggregate = AggregateSerializer(required=False)
     group = GroupSerializer(required=False)
+    groups = GroupsSerializer(required=False)
     timezone = fields.CharField(required=False)
     params = SqlParamsSerializers(required=False)
     params_obj = fields.JSONField(required=False)
@@ -81,36 +93,64 @@ class SqlSerializer(Serializer):
             return select([y_func]).select_from(subquery)
 
     def group_queryset(self, subquery, data, session):
-        y_func_param = data['group'].get('yFunc').lower()
-        x_lookup_param = data['group'].get('xLookup')
-        x_column_param = data['group'].get('xColumn')
-        y_column_param = data['group'].get('yColumn')
+        def get_y_func(group):
+            y_func_param = group.get('yFunc').lower()
+            y_column_param = group.get('yColumn')
+            y_column = column(y_column_param) if y_column_param is not None else None
+            return get_query_func_by_name(y_func_param, y_column)
 
-        x_column = column(x_column_param) if x_column_param is not None else None
-        y_column = column(y_column_param) if y_column_param is not None else None
-        y_func = get_query_func_by_name(y_func_param, y_column)
-
-        x_lookup = get_query_lookup_func_by_name(session, x_lookup_param, x_column)
+        if 'groups' in data:
+            y_func = get_y_func(data['groups'])
+        elif 'group' in data:
+            y_func = get_y_func(data['group'])
+        else:
+            y_func = None
 
         if y_func is None:
             return subquery.filter(sql.false())
-        else:
-            queryset = select([x_lookup.label('group'), y_func.label('y_func')]).select_from(subquery)
-            return queryset.group_by('group').order_by('group')
+
+        def group_name(i):
+            if i == 0:
+                return 'group'
+            else:
+                return 'group_{}'.format(i + 1)
+
+        def map_group_column(group, i):
+            x_lookup_param = group.get('xLookup')
+            x_column_param = group.get('xColumn')
+            x_column = column(x_column_param) if x_column_param is not None else None
+
+            lookup_params = x_lookup_param.split('_') if x_lookup_param else []
+            lookup_type = lookup_params[0] if len(lookup_params) >= 1 else None
+            lookup_param = lookup_params[1] if len(lookup_params) >= 2 else None
+
+            return get_query_lookup_func_by_name(session, lookup_type, lookup_param, x_column).label(group_name(i))
+
+        if 'groups' in data:
+            x_lookups = list(map(lambda x: map_group_column(x[1], x[0]), enumerate(data['groups']['xColumns'])))
+        elif 'group' in data:
+            x_lookups = [map_group_column(data['group'], 0)]
+
+        x_lookup_names = list(map(lambda x: x.name, x_lookups))
+
+        queryset = select([*x_lookups, y_func.label('y_func')]).select_from(subquery)
+        return queryset.group_by(*x_lookup_names).order_by(*x_lookup_names)
 
     def filter_queryset(self, queryset, data):
         filters_instances = []
 
         for item in data.get('columns', []):
-            query_type = map_query_type(item['data_type'])()
+            query_type = map_to_sql_type(item['data_type'])()
             filter_data = filter_for_data_type(query_type)
             for lookup in filter_data['lookups']:
-                instance = filter_data['filter_class'](
-                    name=item['name'],
-                    column=column(item['name']),
-                    lookup=lookup
-                )
-                filters_instances.append(instance)
+                for exclude in [False, True]:
+                    instance = filter_data['filter_class'](
+                        name=item['name'],
+                        column=column(item['name']),
+                        lookup=lookup,
+                        exclude=exclude
+                    )
+                    filters_instances.append(instance)
 
         def get_filter_value(name):
             filter_items = list(filter(lambda x: x['name'] == name, data.get('filters', [])))
@@ -119,10 +159,15 @@ class SqlSerializer(Serializer):
         for item in filters_instances:
             if item.name:
                 argument_name = '{}__{}'.format(item.name, item.lookup)
+                if item.exclude:
+                    argument_name = 'exclude__{}'.format(argument_name)
                 value = get_filter_value(argument_name)
 
                 if value is None and item.lookup == lookups.DEFAULT_LOOKUP:
-                    value = get_filter_value(item.name)
+                    argument_name = item.name
+                    if item.exclude:
+                        argument_name = 'exclude__{}'.format(argument_name)
+                    value = get_filter_value(argument_name)
             else:
                 value = None
 
@@ -133,7 +178,7 @@ class SqlSerializer(Serializer):
         if search not in EMPTY_VALUES:
             def map_column(item):
                 field = column(item['name'])
-                query_type = map_query_type(item['data_type'])()
+                query_type = map_to_sql_type(item['data_type'])()
 
                 if isinstance(query_type, (sqltypes.Integer, sqltypes.Numeric)):
                     return cast(field, sqltypes.String).__eq__(search)
@@ -178,7 +223,7 @@ class SqlSerializer(Serializer):
 
     def execute(self, data):
         request = self.context.get('request')
-        session = create_session(request)
+        session = request.session
 
         query = data['query']
 
@@ -204,23 +249,25 @@ class SqlSerializer(Serializer):
 
                 count_result = session.execute(count_queryset, params)
                 count_rows = count_result.all()[0][0]
+            except SQLAlchemyError:
+                session.rollback()
             except Exception:
                 pass
 
         try:
             if 'aggregate' in data:
                 queryset = self.aggregate_queryset(subquery, data)
-            elif 'group' in data:
+            elif 'groups' in data or 'group' in data:
                 queryset = self.group_queryset(subquery, data, session)
             else:
                 queryset = select(['*']).select_from(subquery)
 
             queryset = self.filter_queryset(queryset, data)
 
-            if 'aggregate' not in data and 'group' not in data:
+            if 'aggregate' not in data and 'group' not in data and 'groups' not in data:
                 queryset = self.paginate_queryset(queryset, data)
 
-            if 'group' not in data:
+            if 'group' not in data and 'groups' not in data:
                 queryset = self.sort_queryset(queryset, data)
 
             result = session.execute(queryset, params)
@@ -242,7 +289,21 @@ class SqlSerializer(Serializer):
             def map_row(row):
                 return list(map(lambda x: map_row_column(row[x]), row.keys()))
 
-            response = {'data': list(map(map_row, result)), 'columns': list(map(map_column, result.keys()))}
+            def map_column_description(column):
+                name = column.name if hasattr(column, 'name') else ''
+                sql_type = type_code_to_sql_type.get(column.type_code) if hasattr(column, 'type_code') else None
+                return name, {
+                    'field': sql_to_map_type(sql_type) if sql_type else None
+                }
+
+            type_code_to_sql_type = get_type_code_to_sql_type(request)
+            column_descriptions = dict(map(map_column_description, result.cursor.description))
+
+            response = {
+                'data': list(map(map_row, result)),
+                'columns': list(map(map_column, result.keys())),
+                'column_descriptions': column_descriptions
+            }
 
             if count_rows is not None:
                 response['count'] = count_rows
