@@ -6,15 +6,26 @@ from sqlalchemy.sql.elements import AnnotatedColumnElement, UnaryExpression
 from jet_bridge_base import settings
 
 
-def get_queryset_model(queryset):
-    return queryset._primary_entity.entity_zero_or_selectable.entity
+def get_queryset_order_by(queryset):
+    if hasattr(queryset, '_order_by_clauses') and queryset._order_by_clauses:
+        return queryset._order_by_clauses
+    elif hasattr(queryset, '_order_by') and queryset._order_by:
+        return queryset._order_by
+    else:
+        return []
 
 
-def apply_default_ordering(queryset):
-    model = get_queryset_model(queryset)
-    mapper = inspect(model)
+def get_queryset_limit(queryset):
+    if hasattr(queryset, '_limit_clause') and queryset._limit_clause:
+        return queryset._limit_clause
+    elif hasattr(queryset, '_limit') and queryset._limit:
+        return queryset._limit
+
+
+def apply_default_ordering(Model, queryset):
+    mapper = inspect(Model)
     pk = mapper.primary_key[0].name
-    ordering = queryset._order_by if queryset._order_by else []
+    ordering = get_queryset_order_by(queryset)
 
     def is_pk(x):
         if isinstance(x, AnnotatedColumnElement):
@@ -51,18 +62,22 @@ def queryset_count_optimized_for_mysql(request, db_table):
 
 def queryset_count_optimized(request, queryset):
     result = None
+    table_size = None
 
-    if queryset.whereclause is None:
-        try:
-            table = queryset.statement.froms[0].name
-            if settings.DATABASE_ENGINE == 'postgresql':
-                result = queryset_count_optimized_for_postgresql(request, table)
-            elif settings.DATABASE_ENGINE == 'mysql':
-                result = queryset_count_optimized_for_mysql(request, table)
-        except:
-            pass
+    try:
+        table = queryset.statement.froms[0].name
 
-    if result is not None and result >= 10000:
+        if get_session_engine(queryset.session) == 'postgresql':
+            table_size = queryset_count_optimized_for_postgresql(request, table)
+        elif get_session_engine(queryset.session) == 'mysql':
+            table_size = queryset_count_optimized_for_mysql(request, table)
+    except:
+        pass
+
+    if queryset.whereclause is None and table_size is not None:
+        result = table_size
+
+    if table_size is not None and table_size >= 10000:
         return result
 
     try:
@@ -70,3 +85,6 @@ def queryset_count_optimized(request, queryset):
     except SQLAlchemyError:
         queryset.session.rollback()
         raise
+
+def get_session_engine(session):
+    return session.bind.engine.name
