@@ -5,9 +5,9 @@ from jet_bridge_base.views.base.api import BaseAPIView
 
 class ApiView(BaseAPIView):
 
-    def get(self, *args, **kwargs):
+    def get(self, request, *args, **kwargs):
         return JSONResponse({
             'version': configuration.get_version(),
             'type': configuration.get_type(),
-            'media_url_template': configuration.media_url('{}', self.request)
+            'media_url_template': configuration.media_url('{}', request)
         })
