@@ -1,4 +1,5 @@
 from jet_bridge_base.exceptions.sql import SqlError
+from jet_bridge_base.exceptions.validation_error import ValidationError
 from jet_bridge_base.permissions import HasProjectPermissions
 from jet_bridge_base.responses.json import JSONResponse
 from jet_bridge_base.serializers.sql import SqlSerializer, SqlsSerializer
@@ -15,7 +16,10 @@ class SqlView(APIView):
         else:
             serializer = SqlSerializer(data=request.data, context={'request': request})
 
-        serializer.is_valid(raise_exception=True)
+        try:
+            serializer.is_valid(raise_exception=True)
+        except ValidationError as e:
+            return JSONResponse({'error': str(e)}, status=HTTP_400_BAD_REQUEST)
 
         try:
             result = serializer.execute(serializer.validated_data)
